
# engineering-economics-basics

## Overview

This package provides some of the basic functions of engineering economics

You can find it at: [https://pypi.org/project/eng-econ/](https://pypi.org/project/eng-econ/)

## Install

```
pip install eng_econ
```

## Usage

```
# Using uniform_gradient_present_worth_factor as an example
from eng_econ.factors import uniform_gradient_present_worth_factor
uniform_gradient_present_worth_factor(0.01, 20)
```

## Documents

See [https://songyu-wang.github.io/engineering-economics-basics/docs/eng_econ/index.html](https://songyu-wang.github.io/engineering-economics-basics/docs/eng_econ/index.html)

## Test Coverage

see [https://songyu-wang.github.io/engineering-economics-basics/htmlcov/index.html](https://songyu-wang.github.io/engineering-economics-basics/htmlcov/index.html)

### Reference

National Council of Examiners for Engineering and Surveying(NCEES). FE Reference Handbook, 9.5 Edition, (ISBN 978-1-932613-67-4).
